@@ -46,6 +46,7 @@ __all__ = (
     "SubscriptionTypeDef",
     "SummarizedAttackVectorTypeDef",
     "SummarizedCounterTypeDef",
+    "TagTypeDef",
     "TimeRangeTypeDef",
     "CreateProtectionResponseTypeDef",
     "DescribeAttackResponseTypeDef",
@@ -60,6 +61,7 @@ __all__ = (
     "ListProtectionGroupsResponseTypeDef",
     "ListProtectionsResponseTypeDef",
     "ListResourcesInProtectionGroupResponseTypeDef",
+    "ListTagsForResourceResponseTypeDef",
     "PaginatorConfigTypeDef",
 )
 
@@ -190,7 +192,8 @@ _OptionalProtectionGroupTypeDef = TypedDict(
             "CLASSIC_LOAD_BALANCER",
             "APPLICATION_LOAD_BALANCER",
             "GLOBAL_ACCELERATOR",
-        ]
+        ],
+        "ProtectionGroupArn": str,
     },
     total=False,
 )
@@ -206,7 +209,7 @@ ProtectionLimitsTypeDef = TypedDict(
 
 ProtectionTypeDef = TypedDict(
     "ProtectionTypeDef",
-    {"Id": str, "Name": str, "ResourceArn": str, "HealthCheckIds": List[str]},
+    {"Id": str, "Name": str, "ResourceArn": str, "HealthCheckIds": List[str], "ProtectionArn": str},
     total=False,
 )
 
@@ -241,6 +244,7 @@ _OptionalSubscriptionTypeDef = TypedDict(
         "AutoRenew": Literal["ENABLED", "DISABLED"],
         "Limits": List["LimitTypeDef"],
         "ProactiveEngagementStatus": Literal["ENABLED", "DISABLED", "PENDING"],
+        "SubscriptionArn": str,
     },
     total=False,
 )
@@ -272,6 +276,8 @@ SummarizedCounterTypeDef = TypedDict(
     total=False,
 )
 
+TagTypeDef = TypedDict("TagTypeDef", {"Key": str, "Value": str}, total=False)
+
 TimeRangeTypeDef = TypedDict(
     "TimeRangeTypeDef", {"FromInclusive": datetime, "ToExclusive": datetime}, total=False
 )
@@ -357,6 +363,10 @@ class ListResourcesInProtectionGroupResponseTypeDef(
     pass
 
 
+ListTagsForResourceResponseTypeDef = TypedDict(
+    "ListTagsForResourceResponseTypeDef", {"Tags": List["TagTypeDef"]}, total=False
+)
+
 PaginatorConfigTypeDef = TypedDict(
     "PaginatorConfigTypeDef", {"MaxItems": int, "PageSize": int, "StartingToken": str}, total=False
 )
